---
name: "[DOCS]"
about: Propose changes or enhancements to documentation
title: "[DOCS] Documentation"
labels: documentation
assignees: ''

---

When something is wrong with the documentation: 

- [ ] please tell us clearly where the mistake is 
- [ ] explain why the mistake is confusing or wrong 
- [ ] suggest a better tone/alternative 

It is also perfectly fine to discuss the examples in the documentation here as well.
